# sosw
[![Build Status](https://travis-ci.org/bimpression/sosw.svg?branch=master)](https://travis-ci.org/bimpression/sosw)

Serverless Orchestrator of Serverless Workers for AWS

## Documentation

[sosw.readthedocs.io](https://sosw.readthedocs.io/en/latest/)
